@@ -2,6 +2,9 @@
 #
 #  main configuration registry classes
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2004-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -53,9 +56,9 @@ from univention.config_registry.handler import run_filter
 if six.PY2:
 	from io import open
 try:
-	from typing import overload, Any, Dict, IO, Iterator, List, ItemsView, NoReturn, Optional, Set, Tuple, Type, TypeVar, Union  # noqa F401
-	from types import TracebackType  # noqa F401
-	from typing_extension import Literal  # noqa F401
+	from typing import overload, Any, Dict, IO, Iterator, List, ItemsView, NoReturn, Optional, Set, Tuple, Type, TypeVar, Union  # noqa: F401
+	from types import TracebackType  # noqa: F401
+	from typing_extension import Literal  # noqa: F401
 	_T = TypeVar('_T', bound='ReadOnlyConfigRegistry')
 	_VT = TypeVar('_VT')
 except ImportError:  # pragma: no cover
@@ -83,7 +86,7 @@ def exception_occured(out=sys.stderr):
 	sys.exit(1)
 
 
-SCOPE = ['normal', 'ldap', 'schedule', 'forced', 'custom', 'default']
+SCOPE = ['default', 'normal', 'ldap', 'schedule', 'forced', 'custom']
 
 
 class Load(IntEnum):
@@ -313,16 +316,16 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
 		return len(merge)
 
 	@overload  # type: ignore
-	def get(self, key, default, getscope):  # noqa F811 # pragma: no cover
+	def get(self, key, default, getscope):  # noqa: F811 # pragma: no cover
 		# type: (str, _VT, Literal[True]) -> Union[Tuple[int, str], _VT]
 		pass
 
 	@overload
-	def get(self, key, default=None):  # noqa F811 # pragma: no cover
+	def get(self, key, default=None):  # noqa: F811 # pragma: no cover
 		# type: (str, _VT) -> Union[str, _VT]
 		pass
 
-	def get(self, key, default=None, getscope=False):  # noqa F811
+	def get(self, key, default=None, getscope=False):  # noqa: F811
 		# type: (str, Optional[_VT], bool) -> Union[str, Tuple[int, str], _VT, None]
 		"""
 		Return registry value (including optional scope).
@@ -343,16 +346,16 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
 		return default
 
 	@overload
-	def get_int(self, key):  # noqa F811 # pragma: no cover
+	def get_int(self, key):  # noqa: F811 # pragma: no cover
 		# type: (str) -> Optional[int]
 		pass
 
 	@overload  # type: ignore
-	def get_int(self, key, default):  # noqa F811 # pragma: no cover
+	def get_int(self, key, default):  # noqa: F811 # pragma: no cover
 		# type: (str, _VT) -> Union[int, _VT]
 		pass
 
-	def get_int(self, key, default=None):  # noqa F811
+	def get_int(self, key, default=None):  # noqa: F811
 		# type: (str, Optional[_VT]) -> Union[int, _VT, None]
 		"""
 		Return registry value as int.
@@ -372,11 +375,11 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
 		pass
 
 	@overload
-	def _merge(self, getscope):  # noqa F811 # pragma: no cover
+	def _merge(self, getscope):  # noqa: F811 # pragma: no cover
 		# type: (Literal[True]) -> Dict[str, Tuple[int, str]]
 		pass
 
-	def _merge(self, getscope=False):  # noqa F811
+	def _merge(self, getscope=False):  # noqa: F811
 		# type: (bool) -> Union[Dict[str, str], Dict[str, Tuple[int, str]]]
 		"""
 		Merge sub registry.
@@ -417,11 +420,11 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
 		pass
 
 	@overload
-	def items(self, getscope):  # noqa F811 # pragma: no cover
+	def items(self, getscope):  # noqa: F811 # pragma: no cover
 		# type: (Literal[True]) -> ItemsView[str, Tuple[int, str]]
 		pass
 
-	def items(self, getscope=False):  # noqa F811
+	def items(self, getscope=False):  # noqa: F811
 		# type: (bool) -> Union[ItemsView[str, str], ItemsView[str, Tuple[int, str]]]
 		"""
 		Return all registry entries a 2-tuple (key, value) or (key, (scope, value)) if getscope is True.
