@@ -3,7 +3,10 @@
 """Univention Configuration Registry command line implementation."""
 #  main configuration registry classes
 #
-# Copyright 2004-2021 Univention GmbH
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
+# Copyright 2004-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -49,7 +52,7 @@ from univention.config_registry.filters import filter_shell, filter_keys_only, f
 if six.PY2:
 	from io import open
 try:
-	from typing import Any, Callable, Dict, IO, Iterator, List, NoReturn, Optional, Tuple  # noqa F401
+	from typing import Any, Callable, Dict, IO, Iterator, List, NoReturn, Optional, Tuple  # noqa: F401
 except ImportError:  # pragma: no cover
 	pass
 
@@ -551,7 +554,7 @@ def handler_help(args, opts={}, out=sys.stdout):
 	"""
 	print(u'''
 univention-config-registry: base configuration for UCS
-copyright (c) 2001-2021 Univention GmbH, Germany
+copyright (c) 2001-2022 Univention GmbH, Germany
 
 Syntax:
   univention-config-registry [options] <action> [options] [parameters]
@@ -614,7 +617,7 @@ Actions:
     no file is specified ALL configuration files are rebuilt
 
   filter [file]:
-    evaluate a template file, expects python inline code in UTF-8 or US-ASCII
+    evaluate a template file, expects Python inline code in UTF-8 or US-ASCII
 
 Description:
   univention-config-registry is a tool to handle the basic configuration for
