@@ -5,7 +5,7 @@ from threading import Thread, Lock
 
 import pytest
 
-from univention.config_registry.backend import ConfigRegistry  # noqa E402
+from univention.config_registry.backend import ConfigRegistry  # noqa: E402
 
 
 class DummyLock(object):
